@@ -78,21 +78,38 @@ weak_alias (__libc_write, __write)
 //#define __NR_open             5
 #ifdef L___syscall_open
 #define __NR___syscall_open __NR_open
+#include <stdlib.h>
 #include <stdarg.h>
 #include <fcntl.h>
+#include <string.h>
+#include <sys/param.h>
 static inline
-_syscall3(int, __syscall_open, const char *, fn, int, flags, __kernel_mode_t, mode);
-int __libc_open (const char * fn, int flags, ...)
+_syscall3(int, __syscall_open, const char *, file, int, flags, __kernel_mode_t, mode);
+int __libc_open (const char * file, int flags, ...)
 {
-	va_list ap;
 	mode_t mode;
-	va_start(ap, flags);
-	mode = va_arg(ap, mode_t);
-	va_end(ap);
-	return __syscall_open(fn, flags, mode);
+	if (unlikely(file==NULL || *file=='\0')) {
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(file)+1) > NAME_MAX))) {
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	if (flags & O_CREAT) {
+		va_list ap;
+		va_start(ap, flags);
+		mode = va_arg(ap, mode_t);
+		va_end(ap);
+	}
+	return __syscall_open(file, flags, mode);
 }
-
 weak_alias(__libc_open, open)
+
+int creat(const char *file, mode_t mode)
+{
+	  return __libc_open (file, O_WRONLY|O_CREAT|O_TRUNC, mode);
+}
 #endif
 
 //#define __NR_close            6
@@ -107,23 +124,7 @@ weak_alias(__libc_close, close)
 // Implemented using wait4 
 
 //#define __NR_creat            8
-#ifdef L___syscall_creat
-#include <fcntl.h>
-#ifdef __NR_creat
-#define __NR___syscall_creat __NR_creat
-_syscall2(int, __syscall_creat, const char *, file, __kernel_mode_t, mode);
-int creat (const char *file, mode_t mode)
-{
-	  return __syscall_creat (file, mode);
-}
-#else
-extern int __libc_open (const char *file, int flags, mode_t mode);
-int creat (const char *file, mode_t mode)
-{
-	  return __libc_open (file, O_WRONLY|O_CREAT|O_TRUNC, mode);
-}
-#endif
-#endif
+// Implemented using open
 
 //#define __NR_link             9
 #ifdef L_link
@@ -138,16 +139,47 @@ _syscall1(int, unlink, const char *, pathname);
 #endif
 
 //#define __NR_execve           11
-#ifdef L_execve
+#ifdef L___syscall_execve
+#define __NR___syscall_execve __NR_execve
 #include <unistd.h>
-_syscall3(int, execve, const char *, filename, char *const *, argv,
-		  char *const *, envp);
+#include <string.h>
+#include <sys/param.h>
+static inline
+_syscall3(int, __syscall_execve, const char *, filename, 
+		char *const *, argv, char *const *, envp);
+int execve(const char *filename, char *const *argv, char *const *envp)
+{ 
+	if (unlikely(filename==NULL || *filename=='\0')) {
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(filename)+1) > NAME_MAX))) {
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	return __syscall_execve(filename, argv, envp);
+}
 #endif
 
 //#define __NR_chdir            12
-#ifdef L_chdir
-#include <unistd.h>
-_syscall1(int, chdir, const char *, path);
+#ifdef L___syscall_chdir
+#define __NR___syscall_chdir __NR_chdir
+#include <string.h>
+#include <sys/param.h>
+static inline
+_syscall1(int, __syscall_chdir, const char *, path);
+int chdir(const char *path)
+{ 
+	if (unlikely(path==NULL || *path=='\0')) {
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(path)+1) > NAME_MAX))) {
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	return __syscall_chdir(path);
+}
 #endif
 
 //#define __NR_time             13
@@ -177,8 +209,8 @@ time_t time (time_t *t)
 _syscall3(int, __syscall_mknod, const char *, path, __kernel_mode_t, mode, __kernel_dev_t, dev);
 int mknod(const char *path, mode_t mode, dev_t dev)
 { 
-	__kernel_dev_t k_dev;
 	/* We must convert the dev_t value to a __kernel_dev_t */
+	__kernel_dev_t k_dev;
 	k_dev = ((major(dev) & 0xff) << 8) | (minor(dev) & 0xff);
 	return __syscall_mknod(path, mode, k_dev);
 }
@@ -211,6 +243,12 @@ static inline
 _syscall3(int, __syscall_lchown, const char *, path, __kernel_uid_t, owner, __kernel_gid_t, group);
 int lchown(const char *path, uid_t owner, gid_t group)
 {
+	if (((owner + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((group + 1) > (gid_t) ((__kernel_gid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return __syscall_lchown(path, owner, group);
 }
 #endif
@@ -262,7 +300,7 @@ static inline
 _syscall1(int, __syscall_setuid, __kernel_uid_t, uid);
 int setuid(uid_t uid)
 {
-	if (uid == (uid_t) ~0 || uid != (uid_t) ((int) uid)) {
+	if (uid == (uid_t) ~0 || uid != (uid_t) ((__kernel_uid_t) uid)) {
 		__set_errno (EINVAL);
 		return -1;
 	}
@@ -304,12 +342,7 @@ int stime(const time_t *when)
 #endif
 
 //#define __NR_ptrace           26
-#ifdef L___ptrace
-#include <sys/ptrace.h>
-#define __NR___ptrace __NR_ptrace
-_syscall4(long, __ptrace, enum __ptrace_request, request, __kernel_pid_t, pid,
-		void*, addr, void*, data);
-#endif
+//See ptrace.c
 
 
 //#define __NR_alarm            27
@@ -468,9 +501,30 @@ int kill(pid_t pid, int sig)
 #endif
 
 //#define __NR_rename           38
-#ifdef L_rename
+#ifdef L___syscall_rename
+#define __NR___syscall_rename __NR_rename
+#include <unistd.h>
+#include <string.h>
+#include <sys/param.h>
 #include <stdio.h>
-_syscall2(int, rename, const char *, oldpath, const char *, newpath);
+static inline
+_syscall2(int, __syscall_rename, const char *, oldpath, const char *, newpath);
+int rename(const char *oldpath, const char *newpath)
+{ 
+	if (unlikely((oldpath==NULL || newpath==NULL ||
+					*oldpath=='\0' || *newpath=='\0'))) 
+	{
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(oldpath)+1) >= NAME_MAX) || 
+				((strlen(newpath)+1) >= NAME_MAX))) 
+	{
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	return __syscall_rename(oldpath, newpath);
+}
 #endif
 
 //#define __NR_mkdir            39
@@ -521,6 +575,12 @@ static inline
 _syscall1(int, __syscall_setgid, __kernel_gid_t, gid);
 int setgid(gid_t gid)
 {
+	if (gid == (gid_t) ~0
+			|| gid != (gid_t) ((__kernel_gid_t) gid))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setgid(gid));
 }
 #endif
@@ -665,17 +725,33 @@ int setpgid(pid_t pid, pid_t pgid)
 #include <sys/stat.h>
 #define __NR___syscall_umask __NR_umask
 static inline 
-_syscall1(__kernel_mode_t, __syscall_umask, __kernel_mode_t, mask);
-mode_t umask(mode_t mask)
+_syscall1(__kernel_mode_t, __syscall_umask, __kernel_mode_t, mode);
+mode_t umask(mode_t mode)
 {
-	return(__syscall_umask(mask));
+	return(__syscall_umask(mode));
 }
 #endif
 
 //#define __NR_chroot           61
-#ifdef L_chroot
+#ifdef L___syscall_chroot
+#define __NR___syscall_chroot __NR_chroot
 #include <unistd.h>
-_syscall1(int, chroot, const char *, path);
+#include <string.h>
+#include <sys/param.h>
+static inline
+_syscall1(int, __syscall_chroot, const char *, path);
+int chroot(const char *path)
+{ 
+	if (unlikely(path==NULL || *path=='\0')) {
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(path)+1) > NAME_MAX))) {
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	return __syscall_chroot(path);
+}
 #endif
 
 //#define __NR_ustat            62
@@ -686,8 +762,8 @@ static inline
 _syscall2(int, __syscall_ustat, unsigned short int, kdev_t, struct ustat *, ubuf);
 int ustat(dev_t dev, struct ustat *ubuf)
 { 
-	__kernel_dev_t k_dev;
 	/* We must convert the dev_t value to a __kernel_dev_t */
+	__kernel_dev_t k_dev;
 	k_dev = ((major(dev) & 0xff) << 8) | (minor(dev) & 0xff);
 	return __syscall_ustat(k_dev, ubuf);
 }
@@ -748,6 +824,12 @@ static inline
 _syscall2(int, __syscall_setreuid, __kernel_uid_t, ruid, __kernel_uid_t, euid);
 int setreuid(uid_t ruid, uid_t euid)
 {
+	if (((ruid + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((euid + 1) > (uid_t) ((__kernel_uid_t) -1U)))
+	{
+		__set_errno(EINVAL);
+		return -1;
+	}
 	return(__syscall_setreuid(ruid, euid));
 }
 #endif
@@ -760,6 +842,12 @@ static inline
 _syscall2(int, __syscall_setregid, __kernel_gid_t, rgid, __kernel_gid_t, egid);
 int setregid(gid_t rgid, gid_t egid)
 {
+	if (((rgid + 1) > (gid_t) ((__kernel_gid_t) -1U))
+			|| ((egid + 1) > (gid_t) ((__kernel_gid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setregid(rgid, egid));
 }
 #endif
@@ -1040,6 +1128,12 @@ static inline
 _syscall3(int, __syscall_fchown, int, fd, __kernel_uid_t, owner, __kernel_gid_t, group);
 int fchown(int fd, uid_t owner, gid_t group)
 {
+	if (((owner + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((group + 1) > (gid_t) ((__kernel_gid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_fchown(fd, owner, group));
 }
 #endif
@@ -1072,9 +1166,25 @@ _syscall3(int, setpriority, __priority_which_t, which, id_t, who, int, prio);
 //#define __NR_profil           98
 
 //#define __NR_statfs           99
-#ifdef L_statfs
+#ifdef L___syscall_statfs
+#define __NR___syscall_statfs __NR_statfs
+#include <string.h>
+#include <sys/param.h>
 #include <sys/vfs.h>
-_syscall2(int, statfs, const char *, path, struct statfs *, buf);
+static inline
+_syscall2(int, __syscall_statfs, const char *, path, struct statfs *, buf);
+int statfs(const char *path, struct statfs *buf)
+{ 
+	if (unlikely(path==NULL || *path=='\0')) {
+		__set_errno(EINVAL);
+		return -1;
+	}
+	if (unlikely(((strlen(path)+1) > NAME_MAX))) {
+		__set_errno(ENAMETOOLONG);
+		return -1;
+	}
+	return __syscall_statfs(path, buf);
+}
 #endif
 
 //#define __NR_fstatfs          100
@@ -1384,6 +1494,8 @@ _syscall2(int, bdflush, int, __func, long int, __data);
 #endif
 
 //#define __NR_sysfs            135
+//_syscall3(int, sysfs, int, option, unsigned int, index, char addr);
+
 
 //#define __NR_personality      136
 #ifdef __NR_personality
@@ -1404,6 +1516,11 @@ static inline
 _syscall1(int, __syscall_setfsuid, __kernel_uid_t, uid);
 int setfsuid(uid_t uid)
 {
+	if (uid != (uid_t) ((__kernel_uid_t) uid))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setfsuid(uid));
 }
 #endif
@@ -1418,6 +1535,11 @@ static inline
 _syscall1(int, __syscall_setfsgid, __kernel_gid_t, gid);
 int setfsgid(gid_t gid)
 {
+	if (gid != (gid_t) ((__kernel_gid_t) gid))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setfsgid(gid));
 }
 #endif
@@ -1677,6 +1799,13 @@ static inline
 _syscall3(int, __syscall_setresuid, __kernel_uid_t, rgid, __kernel_uid_t, egid, __kernel_uid_t, sgid);
 int setresuid(uid_t ruid, uid_t euid, uid_t suid)
 {
+	if (((ruid + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((euid + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((suid + 1) > (uid_t) ((__kernel_uid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setresuid(ruid, euid, suid));
 }
 #endif
@@ -1721,9 +1850,14 @@ int getresuid (uid_t *ruid, uid_t *euid, uid_t *suid)
 #endif	
 
 //#define __NR_poll                     168
-#if defined(L_poll) && defined(__NR_poll) /* uClinux 2.0 doesn't have poll */
+#ifdef L_poll
+#ifdef __NR_poll
 #include <sys/poll.h>
 _syscall3(int, poll, struct pollfd *, fds, unsigned long int, nfds, int, timeout);
+#else
+/* uClinux 2.0 doesn't have poll, emulate it using select */
+#include "poll.c"
+#endif
 #endif
 
 //#define __NR_nfsservctl               169
@@ -1737,6 +1871,13 @@ static inline
 _syscall3(int, __syscall_setresgid, __kernel_gid_t, rgid, __kernel_gid_t, egid, __kernel_gid_t, sgid);
 int setresgid(gid_t rgid, gid_t egid, gid_t sgid)
 {
+	if (((rgid + 1) > (gid_t) ((__kernel_gid_t) -1U))
+			|| ((egid + 1) > (gid_t) ((__kernel_gid_t) -1U))
+			|| ((sgid + 1) > (gid_t) ((__kernel_gid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_setresgid(rgid, egid, sgid));
 }
 #endif
@@ -1886,6 +2027,12 @@ static inline
 _syscall3(int, __syscall_chown, const char *, path, __kernel_uid_t, owner, __kernel_gid_t, group);
 int chown(const char * path, uid_t owner, gid_t group)
 {
+	if (((owner + 1) > (uid_t) ((__kernel_uid_t) -1U))
+			|| ((group + 1) > (gid_t) ((__kernel_gid_t) -1U)))
+	{
+		__set_errno (EINVAL);
+		return -1;
+	}
 	return(__syscall_chown(path, owner, group));
 }
 #endif
@@ -1970,7 +2117,7 @@ int getrlimit (__rlimit_resource_t resource, struct rlimit *rlimits)
 
 //#define __NR_stat64             195
 #ifdef L___syscall_stat64
-#if defined __NR_stat64 && defined __UCLIBC_HAS_LFS__
+#if defined __UCLIBC_HAS_LFS__ && defined __NR_stat64
 #define __NR___syscall_stat64 __NR_stat64
 #include <unistd.h>
 #include <sys/stat.h>
@@ -1992,7 +2139,7 @@ int stat64(const char * file_name, struct stat64 * buf)
 
 //#define __NR_lstat64            196
 #ifdef L___syscall_lstat64
-#if defined __NR_lstat64 && defined __UCLIBC_HAS_LFS__
+#if defined __UCLIBC_HAS_LFS__ && defined __NR_lstat64
 #define __NR___syscall_lstat64 __NR_lstat64
 #include <unistd.h>
 #include <sys/stat.h>
@@ -2014,7 +2161,7 @@ int lstat64(const char * file_name, struct stat64 * buf)
 
 //#define __NR_fstat64            197
 #ifdef L___syscall_fstat64
-#if defined __NR_fstat64 && defined __UCLIBC_HAS_LFS__
+#if defined __UCLIBC_HAS_LFS__ && defined __NR_fstat64
 #define __NR___syscall_fstat64 __NR_fstat64
 #include <unistd.h>
 #include <sys/stat.h>
@@ -2078,7 +2225,7 @@ _syscall3(int, madvise, void*, __addr, size_t, __len, int, __advice);
 #ifdef L___syscall_fcntl64
 #include <stdarg.h>
 #include <fcntl.h>
-#ifdef __UCLIBC_HAS_LFS__
+#if defined __UCLIBC_HAS_LFS__ && defined __NR_fcntl64
 #define __NR___syscall_fcntl64 __NR_fcntl64
 static inline
 _syscall3(int, __syscall_fcntl64, int, fd, int, cmd, long, arg);
